@@ -108,7 +108,7 @@ densityEqualSplit <- function(x, sigma=NULL, ...,
   switch(at,
          pixels = {
            ## pixellate linear network
-           linemask <- as.mask.psp(Llines, ...)
+           linemask <- psp2mask(Llines, ...)
            lineimage <- as.im(linemask, value=0)
            ## extract pixel centres
            xx <- raster.x(linemask)
@@ -683,7 +683,7 @@ resolve.heat.steps <-
   #' ------------- SPACING OF SAMPLE POINTS, dx ---------------
   if(dx.given) {
     if(verbose) splat(" Validating dx =", dx)
-    check.finite(dx)
+    check.finite(dx, xname="dx")
     stopifnot(dx > 0)
     if(finespacing && dx > lmin/3)
       stop(paste("dx must not exceed (shortest nonzero edge length)/3 =",
